@@ -4,20 +4,19 @@ This Module contains high-level classes to easily model a FlowSystem.
 
 from __future__ import annotations
 
-import logging
 from typing import TYPE_CHECKING
 
 import numpy as np
+from loguru import logger
 
 from .components import LinearConverter
-from .core import NumericDataTS, TimeSeriesData
+from .core import TimeSeriesData
 from .structure import register_class_for_io
 
 if TYPE_CHECKING:
     from .elements import Flow
     from .interface import OnOffParameters
-
-logger = logging.getLogger('flixopt')
+    from .types import Numeric_TPS
 
 
 @register_class_for_io
@@ -76,7 +75,7 @@ class Boiler(LinearConverter):
     def __init__(
         self,
         label: str,
-        eta: NumericDataTS,
+        eta: Numeric_TPS,
         Q_fu: Flow,
         Q_th: Flow,
         on_off_parameters: OnOffParameters | None = None,
@@ -163,7 +162,7 @@ class Power2Heat(LinearConverter):
     def __init__(
         self,
         label: str,
-        eta: NumericDataTS,
+        eta: Numeric_TPS,
         P_el: Flow,
         Q_th: Flow,
         on_off_parameters: OnOffParameters | None = None,
@@ -250,7 +249,7 @@ class HeatPump(LinearConverter):
     def __init__(
         self,
         label: str,
-        COP: NumericDataTS,
+        COP: Numeric_TPS,
         P_el: Flow,
         Q_th: Flow,
         on_off_parameters: OnOffParameters | None = None,
@@ -339,7 +338,7 @@ class CoolingTower(LinearConverter):
     def __init__(
         self,
         label: str,
-        specific_electricity_demand: NumericDataTS,
+        specific_electricity_demand: Numeric_TPS,
         P_el: Flow,
         Q_th: Flow,
         on_off_parameters: OnOffParameters | None = None,
@@ -349,7 +348,7 @@ class CoolingTower(LinearConverter):
             label,
             inputs=[P_el, Q_th],
             outputs=[],
-            conversion_factors=[{P_el.label: 1, Q_th.label: -specific_electricity_demand}],
+            conversion_factors=[{P_el.label: -1, Q_th.label: specific_electricity_demand}],
             on_off_parameters=on_off_parameters,
             meta_data=meta_data,
         )
@@ -361,12 +360,12 @@ class CoolingTower(LinearConverter):
 
     @property
     def specific_electricity_demand(self):
-        return -self.conversion_factors[0][self.Q_th.label]
+        return self.conversion_factors[0][self.Q_th.label]
 
     @specific_electricity_demand.setter
     def specific_electricity_demand(self, value):
         check_bounds(value, 'specific_electricity_demand', self.label_full, 0, 1)
-        self.conversion_factors[0][self.Q_th.label] = -value
+        self.conversion_factors[0][self.Q_th.label] = value
 
 
 @register_class_for_io
@@ -437,8 +436,8 @@ class CHP(LinearConverter):
     def __init__(
         self,
         label: str,
-        eta_th: NumericDataTS,
-        eta_el: NumericDataTS,
+        eta_th: Numeric_TPS,
+        eta_el: Numeric_TPS,
         Q_fu: Flow,
         P_el: Flow,
         Q_th: Flow,
@@ -551,7 +550,7 @@ class HeatPumpWithSource(LinearConverter):
     def __init__(
         self,
         label: str,
-        COP: NumericDataTS,
+        COP: Numeric_TPS,
         P_el: Flow,
         Q_ab: Flow,
         Q_th: Flow,
@@ -589,11 +588,11 @@ class HeatPumpWithSource(LinearConverter):
 
 
 def check_bounds(
-    value: NumericDataTS,
+    value: Numeric_TPS,
     parameter_label: str,
     element_label: str,
-    lower_bound: NumericDataTS,
-    upper_bound: NumericDataTS,
+    lower_bound: Numeric_TPS,
+    upper_bound: Numeric_TPS,
 ) -> None:
     """
     Check if the value is within the bounds. The bounds are exclusive.
@@ -611,13 +610,29 @@ def check_bounds(
         lower_bound = lower_bound.data
     if isinstance(upper_bound, TimeSeriesData):
         upper_bound = upper_bound.data
-    if not np.all(value > lower_bound):
+
+    # Convert to NumPy arrays to handle xr.DataArray, pd.Series, pd.DataFrame
+    value_arr = np.asarray(value)
+    lower_arr = np.asarray(lower_bound)
+    upper_arr = np.asarray(upper_bound)
+
+    if not np.all(value_arr > lower_arr):
         logger.warning(
-            f"'{element_label}.{parameter_label}' is equal or below the common lower bound {lower_bound}."
-            f'    {parameter_label}.min={np.min(value)};    {parameter_label}={value}'
+            "'{}.{}' <= lower bound {}. {}.min={} shape={}",
+            element_label,
+            parameter_label,
+            lower_bound,
+            parameter_label,
+            float(np.min(value_arr)),
+            np.shape(value_arr),
         )
-    if not np.all(value < upper_bound):
+    if not np.all(value_arr < upper_arr):
         logger.warning(
-            f"'{element_label}.{parameter_label}' exceeds or matches the common upper bound {upper_bound}."
-            f'    {parameter_label}.max={np.max(value)};    {parameter_label}={value}'
+            "'{}.{}' >= upper bound {}. {}.max={} shape={}",
+            element_label,
+            parameter_label,
+            upper_bound,
+            parameter_label,
+            float(np.max(value_arr)),
+            np.shape(value_arr),
         )
